@@ -5,11 +5,11 @@ extends 'Mojo::Snoo::Base';
 
 use Mojo::Snoo::Multireddit;
 use Mojo::Snoo::Subreddit;
-use Mojo::Snoo::Thing;
+use Mojo::Snoo::Link;
 use Mojo::Snoo::Comment;
 use Mojo::Snoo::User;
 
-our $VERSION = '0.03';
+our $VERSION = '0.10';
 
 has content => (is => 'rw');
 
@@ -21,8 +21,8 @@ sub subreddit {
     shift->_create_object('Mojo::Snoo::Subreddit', @_);
 }
 
-sub thing {
-    shift->_create_object('Mojo::Snoo::Thing', @_);
+sub link {
+    shift->_create_object('Mojo::Snoo::Link', @_);
 }
 
 sub comment {
@@ -107,9 +107,9 @@ Returns a L<Mojo::Snoo::Multireddit> object.
 
 Returns a L<Mojo::Snoo::Subreddit> object.
 
-=head2 thing
+=head2 link
 
-Returns a L<Mojo::Snoo::Thing> object.
+Returns a L<Mojo::Snoo::Link> object.
 
 =head2 comment
 
@@ -119,6 +119,11 @@ Returns a L<Mojo::Snoo::Comment> object.
 
 Returns a L<Mojo::Snoo::User> object.
 
+=head1 WHY SNOO?
+
+Snoo is reddit's alien mascot. Not to be confused
+with L<snu-snu|https://en.wikipedia.org/wiki/Amazon_Women_in_the_Mood>.
+
 =head1 API DOCUMENTATION
 
 Please see the official L<Reddit API documentation|http://www.reddit.com/dev/api>
@@ -127,6 +132,10 @@ OAuth works, see the L<Quick Start|https://github.com/reddit/reddit/wiki/OAuth2-
 and the L<full documentation|https://github.com/reddit/reddit/wiki/OAuth2>. There is
 also a lot of useful information of the L<redditdev subreddit|http://www.reddit.com/r/redditdev>.
 
+=head1 SEE ALSO
+L<ojo::Snoo>
+=cut
+
 =head1 LICENSE
 
 The (two-clause) FreeBSD License. See LICENSE for details.
